| Title: | 'CGAL' Version 4 C++ Header Files |
|---|---|
| Description: | 'CGAL' is a C++ library that aims to provide easy access to efficient and reliable algorithms in computational geometry. Since its version 4, 'CGAL' can be used as standalone header-only library and is available under a double GPL-3|LGPL license. <https://www.cgal.org/>. |
| Authors: | file inst/AUTHORS |
| Maintainer: | Ahmadou Dicko <[email protected]> |
| License: | GPL-3 | file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-07 06:54:30 UTC |
| Source: | https://gitlab.com/dickoa/cgal4h |
'CGAL' is a C++ library that aims to provide easy access to efficient and reliable algorithms in computational geometry. Since its version 4, 'CGAL' can be used as standalone header-only library and is available under a double GPL-3|LGPL license. <https://www.cgal.org/>.
Maintainer: Ahmadou Dicko [email protected]
Useful links:
## Not run: # Include a dependency to cgal4h inside a cpp file // [[Rcpp::depends(cgal4h)]] include <Rcpp.h> ## End(Not run)## Not run: # Include a dependency to cgal4h inside a cpp file // [[Rcpp::depends(cgal4h)]] include <Rcpp.h> ## End(Not run)