Welcome to ClientVPS Mirrors

Help for package cgal4h
Title: 'CGAL' Version 4 C++ Header Files
Version: 0.1.0
Date: 2020-06-25
Author: file inst/AUTHORS
Maintainer: Ahmadou Dicko <mail@ahmadoudicko.com>
Description: 'CGAL' is a C++ library that aims to provide easy access to efficient and reliable algorithms in computational geometry. Since its version 4, 'CGAL' can be used as standalone header-only library and is available under a double GPL-3|LGPL license. https://www.cgal.org/.
Copyright: file inst/COPYRIGHTS
License: GPL-3 | file LICENSE
URL: https://gitlab.com/dickoa/cgal4h
BugReports: https://gitlab.com/dickoa/cgal4h/issues
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.1.0
NeedsCompilation: no
Packaged: 2020-06-25 23:10:43 UTC; ahmadou
Repository: CRAN
Date/Publication: 2020-06-30 15:50:07 UTC

Provides the 'C++' header-only library of CGAL version 4

Description

'CGAL' is a C++ library that aims to provide easy access to efficient and reliable algorithms in computational geometry. Since its version 4, 'CGAL' can be used as standalone header-only library and is available under a double GPL-3|LGPL license. <https://www.cgal.org/>.

Author(s)

Maintainer: Ahmadou Dicko mail@ahmadoudicko.com

See Also

Useful links:

Examples

## Not run: 

# Include a dependency to cgal4h inside a cpp file
// [[Rcpp::depends(cgal4h)]]
include <Rcpp.h>

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.